simpleauth — Transifex v0.9.0 documentation

# Transifex v0.9.0 documentation

Home | Table of contents | Index | Modules
« previous | up | next »

# `simpleauth`

## Views

« <tt class="docutils literal docutils literal docutils literal"><span class="pre">repowatch</span></tt> | up | <tt class="docutils literal"><span class="pre">simplelock</span></tt> »

### Table Of Contents

- `simpleauth`
  - Views

### Browse

- Prev: `repowatch`
- Next: `simplelock`

### You are here:

- Transifex v0.9.0 documentation
  - Table of Contents
    - Transifex Modules
      - `simpleauth`

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Last update:

Jul 19, 2010

« previous | up | next »
© Copyright Indifex and the Transifex Community. Last updated on Jul 19, 2010 using Sphinx.